@@ -36,10 +36,13 @@ typedef unsigned SessionId;
 #define SESSION_ID_INIT			INVALID_SESSION
 #define SESSION_ID_GENERIC		0xFFFFFFFF
 
+struct Gsasl;
+struct Gsasl_session;
+
 class SessionData
 {
 public:
-	enum State { Init, ReceivingAvatar, Established, Game };
+	enum State { Init, ReceivingAvatar, Established, Game, Closed };
 
 	SessionData(boost::shared_ptr<boost::asio::ip::tcp::socket> sock, SessionId id, SessionDataCallback &cb);
 	~SessionData();
@@ -54,6 +57,15 @@ public:
 
 	boost::shared_ptr<boost::asio::ip::tcp::socket> GetAsioSocket();
 
+	bool CreateServerAuthSession(Gsasl *context);
+	bool CreateClientAuthSession(Gsasl *context, const std::string &userName, const std::string &password);
+	bool AuthStep(int stepNum, const std::string &inData);
+	std::string AuthGetUser() const;
+	void AuthSetPassword(const std::string &password);
+	std::string AuthGetPassword() const;
+	std::string AuthGetNextOutMsg() const;
+	int AuthGetCurStepNum() const;
+
 	void SetReadyFlag();
 	void ResetReadyFlag();
 	bool IsReady() const;
@@ -72,8 +84,8 @@ public:
 	void MarkActivityNotice();
 	unsigned GetAutoDisconnectTimerElapsedSec() const;
 
-	unsigned GetMaxNumPlayers() const;
-	void SetMaxNumPlayers(unsigned numPlayers);
+protected:
+	void InternalClearAuthSession();
 
 private:
 	boost::shared_ptr<boost::asio::ip::tcp::socket> m_socket;
@@ -88,7 +100,10 @@ private:
 	bool							m_activityTimeoutNoticeSent;
 	boost::timers::portable::microsec_timer m_autoDisconnectTimer;
 	SessionDataCallback				&m_callback;
-	unsigned						m_maxNumPlayers;
+	Gsasl_session					*m_authSession;
+	int								m_curAuthStep;
+	std::string						m_nextGsaslMsg;
+	std::string						m_password;
 
 	mutable boost::mutex			m_dataMutex;
 };
